@@ -1,3 +1,3 @@
 from robotpy_toolkit_7407.sensors.photonvision.photon_camera import PhotonCamera
 from robotpy_toolkit_7407.sensors.photonvision.photon_odometry import PhotonOdometry, LoadFieldLayout
-from robotpy_toolkit_7407.sensors.photonvision.photon_target import PhotonTarget
\ No newline at end of file
+from robotpy_toolkit_7407.sensors.photonvision.photon_target import PhotonTarget, AprilTag
\ No newline at end of file
